@@ -1,6 +1,6 @@
 package Facebook::Graph::Query;
 BEGIN {
-  $Facebook::Graph::Query::VERSION = '1.0300';
+  $Facebook::Graph::Query::VERSION = '1.0301';
 }
 
 use Any::Moose;
@@ -74,6 +74,9 @@ has since => (
     predicate   => 'has_since',
 );
 
+has ua => (
+    is => 'rw',
+);
 
 sub limit_results {
     my ($self, $limit) = @_;
@@ -184,7 +187,7 @@ sub uri_as_string {
 sub request {
     my ($self, $uri) = @_;
     $uri ||= $self->uri_as_string;
-    my $response = LWP::UserAgent->new->get($uri);
+    my $response = ($self->ua || LWP::UserAgent->new)->get($uri);
     my %params = (response => $response);
     if ($self->has_secret) {
         $params{secret} = $self->secret;
@@ -202,7 +205,7 @@ Facebook::Graph::Query - Simple and fast searching and fetching of Facebook data
 
 =head1 VERSION
 
-version 1.0300
+version 1.0301
 
 =head1 SYNOPSIS
 
